@@ -39,7 +39,7 @@ class TextRLActor:
             gamma=1,
             lambd=1,
             standardize_advantages=True,
-            act_deterministically=False
+            act_deterministically=True
         )
         self.agent = agent
         return agent
