@@ -49,15 +49,14 @@ class TextRLEnv(gym.Env):
             if len([k for k, v in self.model.named_parameters() if 'decoder' in k]) > 0:
                 feature_dict = self.tokenizer([self.gat_obs_input(self.input_item)],
                                               return_tensors='pt',
-                                              add_special_tokens=False).to(
-                    self.model.device)
+                                              add_special_tokens=False).to(self.model.device)
                 predicted = [self.tokenizer.eos_token] + predicted
                 dec_input = torch.tensor([self.tokenizer.convert_tokens_to_ids(predicted)]).to(self.model.device)
                 feature_dict['decoder_input_ids'] = dec_input
                 prediction = self.model(**feature_dict, output_hidden_states=True)
                 outputs = prediction.decoder_hidden_states[-1].squeeze(0)
             else:
-                feature_dict = self.tokenizer([[self.gat_obs_input(self.input_item), p_text]],
+                feature_dict = self.tokenizer([[self.gat_obs_input(self.input_item),p_text]],
                                               return_tensors='pt',
                                               add_special_tokens=False).to(self.model.device)
                 prediction = self.model(**feature_dict, output_hidden_states=True)
